%define srcname	LibreCAD
%define dxfrw_includedir %(pkg-config --cflags-only-I libdxfrw0 | sed 's|-I||g')

Name:		librecad
Summary:	An generic 2D CAD program
Version:	2.1.3
Release:	%mkrel 2
Group:		Graphics
License:	GPLv2
URL:		http://www.librecad.org/
Source0:	https://github.com/LibreCAD/LibreCAD/archive/%{version}/%{srcname}-%{version}.tar.xz
# Originally from Fedora:
Patch0:		LibreCAD-2.0.8-use-system-shapelib.patch
Patch1:		LibreCAD-2.1.3-use-system-libdxfrw.patch
#-----------------------------------------------
BuildRequires:	libdxfrw-devel
BuildRequires:	%{_lib}boost-devel
BuildRequires:	%{_lib}muparser-devel
BuildRequires:	%{_lib}shapelib-devel
BuildRequires:	%{_lib}qt5core-devel
BuildRequires:	%{_lib}qt5gui-devel
BuildRequires:	%{_lib}qt5widgets-devel
BuildRequires:	%{_lib}qt5clucene-devel
BuildRequires:	%{_lib}qt5sql-devel
BuildRequires:	%{_lib}qt5network-devel
BuildRequires:	%{_lib}qt5help-devel
BuildRequires:	%{_lib}qt5svg-devel
BuildRequires:	%{_lib}qt5printsupport-devel
#-----------------------------------------------
Obsoletes:	librecad-devel


%description
LibreCAD is a Qt5 application to design 2D cad drawing based on the community
edition of QCad.

%files
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/mime/packages/*.xml
%{_datadir}/pixmaps/%{name}.png

#%{_datadir}/%{name}/qm/
%{_datadir}/%{name}/fonts/
%{_datadir}/%{name}/patterns/
%{_datadir}/appdata/
%{_datadir}/%{name}/library

%{_libdir}/%{name}/plugins/

#------------------------------------------------------------------------------

%package	doc
Summary:	Documentation for %{name}
Group:		Documentation
BuildArch:	noarch

%description	doc
LibreCAD is an application for computer aided design (CAD) in two dimensions
(2D).

This package contains documentation for LibreCAD.
%files		doc
%doc README.md
%doc %{_datadir}/doc/%{name}/html/

#------------------------------------------------------------------------------

%prep
%setup -qn %{srcname}-%{version}
%apply_patches

echo 'MUPARSER_DIR = %{_prefix}' >> settings_linux.pro
echo 'BOOST_DIR = %{_includedir}' >> settings_linux.pro
echo 'BOOST_LIBDIR = %{_libdir}' >> settings_linux.pro

sed -i 's|$${DXFRW_INCLUDEDIR}|%{dxfrw_includedir}|g' librecad/src/src.pro

# drop bundled libs and use system ones
rm -rf plugins/importshp/shapelib
rm -rf libraries/libdxfrw
rm -rf libraries/muparser

%build
export PATH=%_qt5_bindir:$PATH
%qmake_qt5 librecad.pro
%make

%install
rm -rf %buildroot
# Let's create the directory structure
%__install -d %{buildroot}%{_datadir}/%{name}/{fonts,patterns,qm,library/misc,library/templates,doc}
%__install -d %{buildroot}%{_datadir}/doc/%{name}/html/{classref/html/,img,imgs}
%__install -d %{buildroot}%{_datadir}/applications/
%__install -d %{buildroot}%{_libdir}/%{name}/plugins
%__install -d %{buildroot}%{_datadir}/appdata

# Now install all files
%__install -Dm 755 unix/%{name} %{buildroot}/%{_bindir}/%{name}
%__install -Dm 644 librecad/res/main/%{name}.png %{buildroot}%{_datadir}/pixmaps/%{name}.png
%__install -t %{buildroot}%{_datadir}/%{name}/patterns/ unix/resources/patterns/*.dxf
%__install -t %{buildroot}%{_datadir}/%{name}/fonts/ unix/resources/fonts/*
%__install -t %{buildroot}%{_datadir}/%{name}/library/misc unix/resources/library/misc/*
%__install -t %{buildroot}%{_datadir}/%{name}/library/templates unix/resources/library/templates/*

#%__install -t %{buildroot}%{_datadir}/%{name}/qm/  unix/resources/qm/*.qm

%__install -t %{buildroot}%{_datadir}/appdata/  unix/appdata/*.xml

%__install -t %{buildroot}%{_libdir}/%{name}/plugins/ unix/resources/plugins/*

# Install documentation files
%__install -t %{buildroot}%{_datadir}/doc/%{name}/html librecad/support/doc/*.html

# appdata
install -Dpm644 librecad/support/librecad.appdata.xml %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml

# Create the desktop file
mkdir -p  %{buildroot}%{_datadir}/applications/
desktop-file-install \
	--dir %{buildroot}%{_datadir}/applications \
	--add-category="Qt" \
	--add-category="X-MandrivaLinux-Multimedia-Graphics" \
		desktop/librecad.desktop

install -m0644 -D desktop/librecad.sharedmimeinfo %{buildroot}%{_datadir}/mime/packages/%{name}.xml

%find_lang %{name}


%changelog
* Sun Jun 04 2017 adrianomorselli <adrianomorselli> 2.1.3-2uplos2017
- rebuild against new shapelib
